@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2021 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
+#    Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,10 @@ import re
 import errno
 import gzip
 import tempfile
-import collections
+try:
+    from collections.abc import MutableSet
+except ImportError:
+    from collections import MutableSet
 import hashlib
 import ipaddress
 import atexit
@@ -1802,7 +1805,7 @@ class PathHistory(object):
         self.history = [path,]
         self.index = 0
 
-class OrderedSet(collections.MutableSet):
+class OrderedSet(MutableSet):
     """
     OrderedSet from Python recipe
     http://code.activestate.com/recipes/576694/
